@@ -22,40 +22,35 @@ class IdMappingCollection:
     def idmap_opvl_water(self) -> IdMappingDataframe:
         if self._id_opvl_water is not None:
             return self._id_opvl_water
-        file_path = self.get_idmap_file_path(idmap=IdMapChoices.idmap_opvl_water)
-        self._id_opvl_water = self.get_idmap_df(idmap=IdMapChoices.idmap_opvl_water, file_path=file_path)
+        self._id_opvl_water = self.get_idmap_df_via_choice(idmap=IdMapChoices.idmap_opvl_water)
         return self._id_opvl_water
 
     @property
     def idmap_opvl_water_hymos(self) -> IdMappingDataframe:
         if self._id_opvl_water_hymos is not None:
             return self._id_opvl_water_hymos
-        file_path = self.get_idmap_file_path(idmap=IdMapChoices.idmap_opvl_water_hymos)
-        self._id_opvl_water_hymos = self.get_idmap_df(idmap=IdMapChoices.idmap_opvl_water_hymos, file_path=file_path)
+        self._id_opvl_water_hymos = self.get_idmap_df_via_choice(idmap=IdMapChoices.idmap_opvl_water_hymos)
         return self._id_opvl_water_hymos
 
     @property
     def idmap_hdsr_nsc(self) -> IdMappingDataframe:
         if self._id_hdsr_nsc is not None:
             return self._id_hdsr_nsc
-        file_path = self.get_idmap_file_path(idmap=IdMapChoices.idmap_hdsr_nsc)
-        self._id_hdsr_nsc = self.get_idmap_df(idmap=IdMapChoices.idmap_hdsr_nsc, file_path=file_path)
+        self._id_hdsr_nsc = self.get_idmap_df_via_choice(idmap=IdMapChoices.idmap_hdsr_nsc)
         return self._id_hdsr_nsc
 
     @property
     def idmap_opvl_water_wq(self) -> IdMappingDataframe:
         if self._id_opvl_water_wq is not None:
             return self._id_opvl_water_wq
-        file_path = self.get_idmap_file_path(idmap=IdMapChoices.idmap_opvl_water_wq)
-        self._id_opvl_water_wq = self.get_idmap_df(idmap=IdMapChoices.idmap_opvl_water_wq, file_path=file_path)
+        self._id_opvl_water_wq = self.get_idmap_df_via_choice(idmap=IdMapChoices.idmap_opvl_water_wq)
         return self._id_opvl_water_wq
 
     @property
     def idmap_grondwater_caw(self) -> IdMappingDataframe:
         if self._id_grondwater_caw is not None:
             return self._id_grondwater_caw
-        file_path = self.get_idmap_file_path(idmap=IdMapChoices.idmap_grondwater_caw)
-        self._id_grondwater_caw = self.get_idmap_df(idmap=IdMapChoices.idmap_grondwater_caw, file_path=file_path)
+        self._id_grondwater_caw = self.get_idmap_df_via_choice(idmap=IdMapChoices.idmap_grondwater_caw)
         return self._id_grondwater_caw
 
     @property
@@ -83,15 +78,16 @@ class IdMappingCollection:
         df["histtag"] = df[IdMapColumnChoices.ex_loc.value] + "_" + df[IdMapColumnChoices.ex_par.value]
         return df
 
-    def get_idmap_file_path(self, idmap: IdMapChoices) -> Path:
+    def get_idmap_df_via_choice(self, idmap: IdMapChoices) -> IdMappingDataframe:
         file_name = idmap.value
         file_path = self.fews_config.IdMapFiles[file_name]
-        return file_path
+        idmap_df = self.get_idmap_df_via_path(file_path=file_path)
+        return idmap_df
 
     @classmethod
-    def get_idmap_df(cls, idmap: IdMapChoices, file_path: Path) -> IdMappingDataframe:
-        assert isinstance(idmap, IdMapChoices)
-        assert isinstance(file_path, Path) and file_path.is_file()
+    def get_idmap_df_via_path(cls, file_path: Path) -> IdMappingDataframe:
+        assert isinstance(file_path, Path), f"file_path {file_path} must be a pathlib.Path"
+        assert file_path.is_file(), f"file_path {file_path} does not exist"
         _dict = XmlReader.xml_to_dict(xml_filepath=file_path)
         _list_with_dicts = _dict["idMap"]["map"]
         # use a Dataframe that is extended with custom (filter) methods
@@ -102,7 +98,7 @@ class IdMappingCollection:
             IdMapColumnChoices.int_loc.value,
             IdMapColumnChoices.int_par.value,
         ]
-        file_name = idmap.value
+        file_name = file_path.stem
         df["source"] = file_name
         df = cls.add_column_histtag(df=df)
         return df
