@@ -1,4 +1,4 @@
-from hdsr_wis_config_reader.constants import paths
+from hdsr_wis_config_reader import constants
 from hdsr_wis_config_reader.tests.fixtures import loc_sets
 
 import pandas as pd  # noqa pandas comes with geopandas
@@ -550,7 +550,7 @@ expected_attrib_files_1_and_2 = [
 
 
 def test_sublocationset(loc_sets):
-    assert loc_sets.subloc.fews_config.path == paths.WIS_CONFIG_TEST_DIR
+    assert loc_sets.subloc.fews_config.path == constants.WIS_CONFIG_TEST_DIR
     assert loc_sets.subloc.idmap_section_name == expected_idmap_section_name
     assert loc_sets.subloc.name == expected_name
     assert loc_sets.subloc.csv_filename == expected_csvfile
